lavalink_rs.model.http API documentation

# lavalink_rs.model.http

class UpdatePlayer:

Updates or creates the player for this guild.

If every field is None, the player will stop playing.

identifier: Optional[str]

The identifier of the track to play.

Mutually exclusive with `encoded_track`.

position: Optional[int]

The track position in milliseconds.

This value can be set to start a track at a specific time.

paused: Optional[bool]

Whether the player should be paused.

filters: Optional[Filters]

The filters to apply.

This will override all previously applied filters.

volume: Optional[int]

The player volume.

In percentage, from 0 to 1000.

end_time: Optional[int]

The track end time in milliseconds.

It must be a value above 0 or None.

None resets this if it was set previously.

voice: Optional[ConnectionInfo]

The discord websocket connection information.

Required for creating a player.

encoded_track: Optional[str]

The base64 encoded track to play.

Mutually exclusive with `identifier`.

class ResumingState:

Updates the session with the resuming state and timeout.

You must call this method if you wish to restart the discord bot without having all players stop, and provide the current `session_id` when creating the node connection.

timeout: Optional[int]

The timeout in seconds.

default is 60s

resuming: Optional[bool]

Whether resuming should be, or is enabled for this session or not.

class Info:

Information about the Lavalink node.

version: lavalink_rs.model.http.Version

The semver version of the Lavalink server.

lavaplayer: str

The Lavaplayer version being used by the Lavalink server.

build_time: int

The millisecond unix timestamp when the Lavalink jar was built.

plugins: List[lavalink_rs.model.http.Plugin]

The enabled plugins for the Lavalink server.

filters: List[str]

The enabled filters for the Lavalink server.

git: lavalink_rs.model.http.Git

The git information of the Lavalink server.

jvm: str

The JVM version the Lavalink server is running on.

source_managers: List[str]

The enabled source managers for the Lavalink server.

class Git:
branch: str

The branch the Lavalink server was built on.

commit_time: int

The millisecond unix timestamp for when the commit was created.

commit: str

The commit the Lavalink server was built on.

class Plugin:
version: str

The version of the plugin

name: str

The name of the plugin

class Version:

Check out Semantic Versioning 2.0.0 to know what these fields mean.

patch: int
pre_release: Optional[str]
semver: str
major: int
build: Optional[str]
minor: int